==> boo_0.7.6.2237.orig.tar.gz: boo-0.7.6.2237/src/Boo.Lang.Compiler/Util/TaskList.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;

namespace Boo.Lang.Compiler.Util
{
	/// <summary>
	/// Uma lista de tarefas.
	/// </summary>
	public class TaskList
	{
		System.Collections.ArrayList _tasks = new System.Collections.ArrayList();

		/// <summary>
		/// Nmero de tarefas na lista.
		/// </summary>
		public int Count
		{
			get
			{
				return _tasks.Count;
			}
		}

		/// <summary>
		/// Adiciona uma nova tarefa  lista.
		/// </summary>
		/// <param name="task"></param>
		public void Add(ITask task)
		{
			if (null == task)
			{
				throw new ArgumentNullException("task");
			}
			_tasks.Add(task);
		}

		/// <summary>
		/// Executa todas as tarefas pendentes na lista.
		/// </summary>
		public void Flush()
		{
			try
			{
				for (int i=_tasks.Count; i>0; --i)
				{
					ITask task = (ITask)_tasks[i-1];
					task.Execute();
				}
			}
			finally
			{
				_tasks.Clear();
			}
		}
	}
}

==> boo_0.8.0.2730.orig.tar.gz: boo-0.8.0.2730/src/Boo.Lang.Compiler/Util/TaskList.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;

namespace Boo.Lang.Compiler.Util
{
	public class TaskList
	{
		System.Collections.ArrayList _tasks = new System.Collections.ArrayList();

		public int Count
		{
			get
			{
				return _tasks.Count;
			}
		}

		public void Add(ITask task)
		{
			if (null == task)
			{
				throw new ArgumentNullException("task");
			}
			_tasks.Add(task);
		}

		public void Flush()
		{
			try
			{
				foreach (ITask task in _tasks)
				{
					task.Execute();
				}
			}
			finally
			{
				_tasks.Clear();
			}
		}
	}
}
